Welcome to MyTB (My Toolbox)

MyTB is just another collection of handy and useful python functions and modules.


.. image:: https://travis-ci.com/feenes/mytb.svg?branch=master
    :target: https://travis-ci.com/feenes/mytb


It can be found at https://github.com/feenes/mytb.git

It tries to be modular in order to consume as little memory (RAM) as possible.

Getting started
===============

Installation
------------

With pip ::

    pip install mytb # basic installation with basic dependencies
    pip install mytb[date] # with all dependencies for mytb.date
    pip install mytb[gitlab] # with all dependencies for mytb.gitlab
    pip install mytb[all] # with all dependencies

    **!!version 0.1 is only python 3 compatible!!**
    Use `pip install 'mytb<0.1'` to get the latest python2 compatible version

Who's using mytb
==================

Please contact us if you want to be referenced

    * MHComm ( https://mhcomm.fr ) for some of their software
    * The timon project ( https://github.com/feenes/timon )

